# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .active_receipt_rule_set import *
from .confguration_set import *
from .configuration_set import *
from .domain_dkim import *
from .domain_identity import *
from .domain_identity_verification import *
from .email_identity import *
from .event_destination import *
from .identity_notification_topic import *
from .identity_policy import *
from .mail_from import *
from .receipt_filter import *
from .receipt_rule import *
from .receipt_rule_set import *
from .template import *
from ._inputs import *
from . import outputs

def _register_module():
    import pulumi

    class Module(pulumi.runtime.ResourceModule):
        def version(self):
            return None

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "aws:ses/activeReceiptRuleSet:ActiveReceiptRuleSet":
                return ActiveReceiptRuleSet(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/confgurationSet:ConfgurationSet":
                return ConfgurationSet(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/configurationSet:ConfigurationSet":
                return ConfigurationSet(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/domainDkim:DomainDkim":
                return DomainDkim(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/domainIdentity:DomainIdentity":
                return DomainIdentity(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/domainIdentityVerification:DomainIdentityVerification":
                return DomainIdentityVerification(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/emailIdentity:EmailIdentity":
                return EmailIdentity(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/eventDestination:EventDestination":
                return EventDestination(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/identityNotificationTopic:IdentityNotificationTopic":
                return IdentityNotificationTopic(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/identityPolicy:IdentityPolicy":
                return IdentityPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/mailFrom:MailFrom":
                return MailFrom(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/receiptFilter:ReceiptFilter":
                return ReceiptFilter(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/receiptRule:ReceiptRule":
                return ReceiptRule(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/receiptRuleSet:ReceiptRuleSet":
                return ReceiptRuleSet(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:ses/template:Template":
                return Template(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("aws", "ses/activeReceiptRuleSet", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/confgurationSet", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/configurationSet", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/domainDkim", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/domainIdentity", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/domainIdentityVerification", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/emailIdentity", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/eventDestination", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/identityNotificationTopic", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/identityPolicy", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/mailFrom", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/receiptFilter", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/receiptRule", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/receiptRuleSet", _module_instance)
    pulumi.runtime.register_resource_module("aws", "ses/template", _module_instance)

_register_module()
